@@ -7,22 +7,18 @@ use warnings;
 use LWP::UserAgent;
 use JSON;
 use URI::Encode qw(uri_encode);
-use File::Basename;
-use File::Path qw(make_path);
 
-$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
 use IO::Socket::SSL;
 IO::Socket::SSL::set_ctx_defaults( 
      SSL_verifycn_scheme => 'www', 
      SSL_verify_mode => 0,
-     verify_mode => 0,
 );
 
-our $VERSION = '1.29.0';
+our $VERSION = '1.12';
 
 =head1 NAME
 
-WebService::Browshot - Perl extension for Browshot (L<https://browshot.com/>), a web service to create screenshots of web pages.
+WebService::Browshot - Perl extension for Browshot (L<http://www.browshot.com/>), a web service to create website screenshots.
 
 =head1 SYNOPSIS
 
@@ -78,7 +74,7 @@ Optional. Set the request timeout - in seconds - against the API. Defaults to 90
 
 =back
 
-C<last_error> contains the last error message, it is NEVER reset, i.e last_error may not be empty after a successful API call if an earlier call failed.
+C<last_error> contasin the last error message, it is NEVER reset, i.e last_error may not be empty after a succesfull API call if an earlier call failed.
 
 =cut
 
@@ -90,7 +86,6 @@ sub new {
 	$ua->env_proxy;
 	$ua->max_redirect(32); # for the simple API only
 	$ua->agent("WebService::Browshot $VERSION");
-	$ua->ssl_opts( verify_hostnames => 0 );
 
   	my $browshot = {	
 		_key	=> $args{key}	|| '',
@@ -153,9 +148,9 @@ sub simple {
 	my $url	= $self->make_url(action => 'simple', parameters => { %args });
 	my $res = $self->{_ua}->get($url);
 
-	# $self->info($res->message);
-	# $self->info($res->request->as_string);
-	# $self->info($res->as_string);
+# 	$self->info($res->message);
+# 	$self->info($res->request->as_string);
+# 	$self->info($res->as_string);
 	
 	return ($res->code, $res->decoded_content);
 }
@@ -164,7 +159,7 @@ sub simple {
 
    $browshot->simple_file(url => 'http://mobilito.net', file => '/tmp/mobilito.png')
 
-Retrieve a screenshot and save it locally in one function. Note: by default, screenshots are cached for 24 hours. You can tune this value with the cache=X parameter.
+Retrieve a screenshot and save it locally in one function. Note: by default, screenshots are cached for 24 hours. You can tune this valu with the cache=X parameter.
 
 Return an array (status code, file name). The file name is empty if the screenshot was not retrieved. See L<http://browshot.com/api/documentation#simple> for the list of possible status codes.
 
@@ -188,12 +183,7 @@ Required. Local file name to write to.
 
 sub simple_file {
 	my ($self, %args) 	= @_;
-	my $file		= $args{file}	|| $self->error("Missing file in simple_file");
-	
-	if (-d $file) {
-		$self->error("You must specify a file path, not a folder, to save the screenshot");
-		return (400, '');
-	}
+	my $file			= $args{file}	|| $self->error("Missing file in simple_file");
 
 	my $url	= $self->make_url(action => 'simple', parameters => { %args });
 	my $res = $self->{_ua}->get($url);
@@ -226,6 +216,18 @@ sub instance_list {
 	return $self->return_reply(action => 'instance/list');
 }
 
+=head2 instance_create()
+
+Create a private instance. See L<http://browshot.com/api/documentation#instance_create> for the response format.
+
+=cut
+
+sub instance_create {
+	my ($self, %args) = @_;
+	
+	return $self->return_reply(action => 'instance/create', parameters => { %args });
+}
+
 =head2 instance_info()
 
    $browshot->instance_info(id => 2)
@@ -246,7 +248,7 @@ Required. Instance ID
 
 sub instance_info  {
 	my ($self, %args) 	= @_;
-	my $id							= $args{id}	|| $self->error("Missing id in instance_info");
+	my $id				= $args{id}	|| $self->error("Missing id in instance_info");
 
 	return $self->return_reply(action => 'instance/info', parameters => { id => $id });
 }
@@ -288,13 +290,24 @@ sub browser_info  {
 	return $self->return_reply(action => 'browser/info', parameters => { id => $id });
 }
 
+=head2 browser_create()
+
+Create a custom browser. See L<http://browshot.com/api/documentation#browser_create> for the response format.
+
+=cut
+
+sub browser_create {
+	my ($self, %args) = @_;
+	
+	return $self->return_reply(action => 'browser/create', parameters => { %args });
+}
 
 =head2 screenshot_create()
 
   $browshot->screenshot_create(url => 'http://wwww.google.com/', instance_id => 3, size => 'page')
 
 Request a screenshot. See L<http://browshot.com/api/documentation#screenshot_create> for the response format.
-Note: by default, screenshots are cached for 24 hours. You can tune this value with the cache=X parameter.
+Note: by default, screenshots are cached for 24 hours. You can tune this valu with the cache=X parameter.
 
 Arguments:
 
@@ -320,12 +333,12 @@ Optional. Screenshot size.
 
 sub screenshot_create {
 	my ($self, %args) 	= @_;
-	# my $url				= $args{url}			|| $self->error("Missing url in screenshot_create");
-	# my $instance_id		= $args{instance_id};
-	# my $screen			= $args{screen};
-	# my $size			= $args{size}			|| "screen";
-	# my $cache			= $args{cache};
-	# my $priority		= $args{priority};
+# 	my $url				= $args{url}			|| $self->error("Missing url in screenshot_create");
+# 	my $instance_id		= $args{instance_id};
+# 	my $screen			= $args{screen};
+# 	my $size			= $args{size}			|| "screen";
+# 	my $cache			= $args{cache};
+# 	my $priority		= $args{priority};
 
 	$self->error("Missing url in screenshot_create") 	if (! defined($args{url}));
 # 	$args{size} = "screen" 					if (! defined($args{size}));
@@ -403,14 +416,14 @@ Required. URL string to look for.
 
 sub screenshot_search {
 	my ($self, %args) 	= @_;
-	my $url			= $args{url}	|| $self->error("Missing url in screenshot_search");
+	my $url			= $args{url}	|| $self->error("Missing id in screenshot_search");
 
 	return $self->return_reply(action => 'screenshot/search', parameters => { %args });
 }
 
 =head2 screenshot_host()
 
-  $browshot->screenshot_host(id => 12345, hosting => 'browshot')
+  $browshot->screenshot_host(id => 12345, hosting => 'cdn')
 
 Host a screenshot or thumbnail. See L<http://browshot.com/api/documentation#screenshot_host> for the response format.
 
@@ -499,7 +512,7 @@ sub screenshot_thumbnail {
 
 =head2 screenshot_thumbnail_file()
 
-  $browshot->screenshot_thumbnail_file(id => 123456, height => 500, file => '/tmp/google.png')
+  $browshot->screenshot_thumbnail_file(url => 'https://ww.browshot.com/screenshot/image/52942?key=my_key', height => 500, file => '/tmp/google.png')
 
 Retrieve the screenshot, or a thumbnail, and save it to a file. See L<http://browshot.com/api/documentation#thumbnails> for the response format.
 
@@ -532,16 +545,10 @@ Optional. Maximum height of the thumbnail.
 =cut
 sub screenshot_thumbnail_file {
 	my ($self, %args) 	= @_;
-	my $file		= $args{file}	|| $self->error("Missing file in screenshot_thumbnail_file");
+	my $file			= $args{file}	|| $self->error("Missing file in screenshot_thumbnail_file");
 
-	delete($args{file});
 	my $content = $self->screenshot_thumbnail(%args);
 
-	my $dir = dirname($file);
-	if (! -d $dir) {
-		make_path($dir)
-	}
-
 	if ($content ne '') {
 		open TARGET, "> $file" or $self->error("Cannot open $file for writing: $!");
 		binmode TARGET;
@@ -610,183 +617,11 @@ Optional. Information to delete.
 
 sub screenshot_delete {
 	my ($self, %args) 	= @_;
-	my $id			= $args{id}	|| $self->error("Missing id in screenshot_delete");
+	my $id				= $args{id}	|| $self->error("Missing id in screenshot_delete");
 
 	return $self->return_reply(action => 'screenshot/delete', parameters => { %args });
 }
 
-=head2 screenshot_html()
-
-  $browshot->screenshot_html(id => 12345)
-
-Get the HTML code of the rendered page. See L<http://browshot.com/api/documentation#screenshot_html> for the response format.
-
-Arguments:
-
-=over 4
-
-=item id
-
-Required. Screenshot ID.
-
-=back
-
-=cut
-
-sub screenshot_html {
-	my ($self, %args) 	= @_;
-	my $id			= $args{id}	|| $self->error("Missing id in screenshot_html");
-
-	return $self->return_string(action => 'screenshot/html', parameters => { %args });
-}
-
-=head2 screenshot_multiple()
-
-  $browshot->screenshot_multiple(urls => ['http://mobilito.net/'], instances => [22, 30])
-
-Request multiple screenshots. See L<http://browshot.com/api/documentation#screenshot_multiple> for the response format.
-
-Arguments:
-
-=over 4
-
-=item urls
-
-Required. One or more URLs.
-
-=item instances
-
-Required. One or more instance_id.
-
-=back
-
-=cut
-
-sub screenshot_multiple {
-	my ($self, %args) 	= @_;
-# 	my $urls		= $args{urls}		|| $self->error("Missing urls in screenshot_multiple");
-# 	my $instances		= $args{instances}	|| $self->error("Missing instances in screenshot_multiple");
-
-	return $self->return_reply(action => 'screenshot/multiple', parameters => { %args });
-}
-
-
-=head2 batch_create()
-
-  $browshot->batch_create(file => '/my/file/urls.txt', instance_id => 65)
-
-Request multiple screenshots from a text file. See L<http://browshot.com/api/documentation#batch_create> for the response format.
-
-Arguments:
-
-=over 4
-
-=item file
-
-Required. Path to the text file which contains the list of URLs.
-
-=item instance_id
-
-Required. instance_id to use for all screenshots.
-
-=back
-
-=cut
-
-sub batch_create {
-	my ($self, %args) 	= @_;
-	my $file		= $args{file}		|| $self->error("Missing file in batch_create");
-	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id in batch_create");
-
-	delete $args{file};
-	return $self->return_post_reply(action => 'batch/create', parameters => { %args }, file => $file);
-}
-
-=head2 batch_info()
-
-  $browshot->batch_info(id => 5)
-
-Get information about a screenshot batch requested previously. See L<http://browshot.com/api/documentation#batch_info> for the response format.
-
-Arguments:
-
-=over 4
-
-=item id
-
-Required. Batch ID.
-
-=back
-
-=cut
-
-sub batch_info {
-	my ($self, %args) 	= @_;
-	my $id			= $args{id}	|| $self->error("Missing id in batch_info");
-
-	return $self->return_reply(action => 'batch/info', parameters => { %args });
-}
-
-
-=head2 crawl_create()
-
-  $browshot->crawl_create(domain => 'blitapp.com', url => 'https://blitapp.com/', max => 50, instance_id => 65)
-
-Crawl a domain and screenshot all pages. See L<http://browshot.com/api/documentation#crawl_create> for the response format.
-
-Arguments:
-
-=over 4
-
-=item domain
-
-Required. Domain to crawl.
-
-=item url
-
-Required. URl to start with.
-
-=item instance_id
-
-Required. instance_id to use for all screenshots.
-
-=back
-
-=cut
-
-sub crawl_create {
-	my ($self, %args) = @_;
-	my $domain				= $args{domain}			|| $self->error("Missing domain in crawl_create");
-	my $url						= $args{url}				|| $self->error("Missing url in crawl_create");
-	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id in crawl_create");
-
-	return $self->return_reply(action => 'crawl/create', parameters => { %args });
-}
-
-=head2 crawl__info()
-
-  $browshot->crawl__info(id => 5)
-
-Get information about a crawl_ requested previously. See L<http://browshot.com/api/documentation#crawl__info> for the response format.
-
-Arguments:
-
-=over 4
-
-=item id
-
-Required. Crawl ID.
-
-=back
-
-=cut
-
-sub crawl_info {
-	my ($self, %args) 	= @_;
-	my $id			= $args{id}	|| $self->error("Missing id in crawl_info");
-
-	return $self->return_reply(action => 'crawl/info', parameters => { %args });
-}
 
 =head2 account_info()
 
@@ -797,14 +632,16 @@ Return information about the user account. See L<http://browshot.com/api/documen
 sub account_info {
 	my ($self, %args) = @_;
 	
-	return $self->return_reply(action => 'account/info', parameters => { %args });
+	return $self->return_reply(action => 'account/info');
 }
 
 
 # Private methods
 
-sub return_string {
+sub return_reply {
 	my ($self, %args) 	= @_;
+# 	my $action			= $args{action};
+# 	my $parameters		= $args{parameters};
 
 	my $url	= $self->make_url(%args);
 	
@@ -821,107 +658,41 @@ sub return_string {
 	}
 	until($try < $self->{_retry} && defined $@);
 
-	if (! $res->is_success) {
-		$self->error("Server sent back an error: " . $res->code);
-	}
-  
-	return $res->decoded_content;
-}
-
-sub return_post_string {
-	my ($self, %args) 	= @_;
-	my $file 		= $args{'file'} || '';
-
-	delete $args{'file'};
-	my $url	= $self->make_url(%args);
-	
-	my $res;
-	my $try = 0;
-
-	do {
-		$self->info("Try $try");
+	if ($res->is_success) {
+		my $info;
 		eval {
-			$res = $self->{_ua}->post(
-			  $url,
-			  Content_Type => 'form-data',
-			  Content => [
-			    file => [$file],
-			  ]
-			);
+			$info = decode_json($res->decoded_content);
 		};
-		$self->error($res->request->as_string) if ($@);
-		$self->error($@) if ($@);
-		$try++;
-	}
-	until($try < $self->{_retry} && defined $@);
+		if ($@) {
+			$self->error("Invalid server response: " . $@);
+			return $self->generic_error($@);
+		}
 
-	if (! $res->is_success) {
+		return $info;
+	}
+	else {
 		$self->error("Server sent back an error: " . $res->code);
-		$self->info($res->request->as_string);
-		$self->info($res->as_string);
+		my $info;
+		eval {
+			$info = decode_json($res->decoded_content);
+		};
+		if ($@) {
+		  return $self->generic_error($res->as_string);
+		}
+
+		return $info;
 	}
-  
-	return $res->decoded_content;
-}
-
-sub return_reply {
-	my ($self, %args) 	= @_;
-
-	my $content = $self->return_string(%args);
-
-	my $info;
-	eval {
-		$info = decode_json($content);
-	};
-	if ($@) {
-		$self->error("Invalid server response: " . $@);
-		return $self->generic_error($@);
-	}
-
-	return $info;
-}
-
-sub return_post_reply {
-	my ($self, %args) 	= @_;
-
-	my $content = $self->return_post_string(%args);
-
-	my $info;
-	eval {
-		$info = decode_json($content);
-	};
-	if ($@) {
-		$self->error("Invalid server response: " . $@);
-		return $self->generic_error($@);
-	}
-
-	return $info;
 }
 
 sub make_url {
 	my ($self, %args) 	= @_;
-	my $action		= $args{action}		|| '';
+	my $action			= $args{action}		|| '';
 	my $parameters		= $args{parameters}	|| { };
 
 	my $url = $self->{_base} . "$action?key=" . uri_encode($self->{_key}, 1);
 
-
-	if (exists $parameters->{urls}) {
-	  foreach my $uri (@{ $parameters->{urls} }) {
-	    $url .= '&url=' . uri_encode($uri, 1);
-	  }
-	  delete  $parameters->{urls};
-	}
-
-	if (exists $parameters->{instances}) {
-	  foreach my $instance_id (@{ $parameters->{instances} }) {
-	    $url .= '&instance_id=' . uri_encode($instance_id, 1);
-	  }
-	  delete  $parameters->{instances};
-	}
-
 	foreach my $key (keys %$parameters) {
-	  $url .= '&' . uri_encode($key) . '=' . uri_encode($parameters->{$key}, 1) if (defined $parameters->{$key});
+		$url .= '&' . uri_encode($key) . '=' . uri_encode($parameters->{$key}, 1) if (defined $parameters->{$key});
 	}
 
 	$self->info($url);
@@ -932,7 +703,7 @@ sub info {
 	my ($self, $message) = @_;
 
 	if ($self->{_debug}) {
-	  print $message, "\n";
+		print $message, "\n";
 	}
 
 	return '';
@@ -961,26 +732,6 @@ sub generic_error {
 
 =over 4
 
-=item 1.24.0
-
-C<screenshot_thumbnail_file> creates the directory structure as needed.
-
-=item 1.16.0
-
-Check if the file is not a folder in simple_file
-
-=item 1.14.1
-
-Remove deprecated API calls.
-
-=item 1.14.0
-
-Add C<batch_create> and C<batch_info> for API 1.14.
-
-=item 1.13.0
-
-Add C<screenshot_html> and C<screenshot_multiple> for API 1.13.
-
 =item 1.12
 
 Add C<screenshot_search> for API 1.12.
@@ -1049,7 +800,7 @@ Julien Sobrier, E<lt>julien@sobrier.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Julien Sobrier
+Copyright (C) 2012 by Julien Sobrier
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
